# Examples   
Our most robust examples showing all sorts of implementations
can be found in our sister library [PyTorch-Lightning-Bolts](https://pytorch-lightning-bolts.readthedocs.io/en/latest/convolutional.html#gpt-2).

---

## Basic examples
In this folder we add 3 simple examples:

* [Image Classifier](https://github.com/PyTorchLightning/pytorch-lightning/blob/master/pl_examples/basic_examples/image_classifier.py) (trains arbitrary datasets with arbitrary backbones).
* [MNIST classifier](https://github.com/PyTorchLightning/pytorch-lightning/blob/master/pl_examples/basic_examples/mnist.py) (defined the model inside the lightningModule).
* [Autoencoder](https://github.com/PyTorchLightning/pytorch-lightning/blob/master/pl_examples/basic_examples/autoencoder.py) (shows how the LightningModule is meant to be used as a system)

---

## Domain examples
This folder contains older examples. You should instead use the examples 
in [PyTorch-Lightning-Bolts](https://pytorch-lightning-bolts.readthedocs.io/en/latest/convolutional.html#gpt-2) 
for advanced use cases.
